@@ -3,6 +3,7 @@ package uo
 import (
 	"fmt"
 	"reflect"
+	"regexp"
 )
 
 func (uo *UnstructuredObject) GetNestedField(keys ...interface{}) (interface{}, bool, error) {
@@ -77,6 +78,34 @@ func (uo *UnstructuredObject) RemoveNestedField(keys ...interface{}) error {
 	return nil
 }
 
+func (uo *UnstructuredObject) RemoveFieldsByPathRegex(path string) error {
+	r, err := regexp.Compile(path)
+	if err != nil {
+		return err
+	}
+
+	var toDelete []KeyPath
+	err = uo.NewIterator().IterateLeafs(func(it *ObjectIterator) error {
+		jp := it.KeyPath().ToJsonPath()
+		if r.MatchString(jp) {
+			toDelete = append(toDelete, it.KeyPathCopy())
+		}
+		return nil
+	})
+	if err != nil {
+		return err
+	}
+
+	for _, p := range toDelete {
+		err = uo.RemoveNestedField(p...)
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func (uo *UnstructuredObject) GetNestedString(keys ...interface{}) (string, bool, error) {
 	v, found, err := uo.GetNestedField(keys...)
 	if err != nil {
@@ -153,6 +182,10 @@ func (uo *UnstructuredObject) GetNestedObject(keys ...interface{}) (*Unstructure
 		return nil, false, nil
 	}
 
+	if a == nil {
+		return nil, true, nil
+	}
+
 	m, ok := a.(map[string]interface{})
 	if !ok {
 		return nil, false, fmt.Errorf("nested value is not a map")
